===================
 Setting Up SQLite
===================

No explicit setup is needed. The necessary files will be created automatically.

For information on backing up the database, see
:ref:`the FAQ about backing up SQLite <backing-up-sqlite>`.
